package com.hfkj.service.order.impl;

import com.alibaba.fastjson.JSONObject;
import com.hfkj.dao.BsOrderChildMapper;
import com.hfkj.dao.GoodsUserAddressMapper;
import com.hfkj.entity.BsOrderChild;
import com.hfkj.entity.BsOrderChildExample;
import com.hfkj.entity.BsOrderGoods;
import com.hfkj.entity.GoodsUserAddress;
import com.hfkj.model.order.OrderChildModel;
import com.hfkj.service.goods.BsOrderGoodsService;
import com.hfkj.service.goods.GoodsUserAddressService;
import com.hfkj.service.goods.GoodsVpdService;
import com.hfkj.service.order.BsOrderChildService;
import com.hfkj.sysenum.order.OrderChildProductTypeEnum;
import com.hfkj.sysenum.order.OrderChildStatusEnum;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @className: BsOrderChildServiceImpl
 * @author: HuRui
 * @date: 2024/5/6
 **/
@Service("orderChildService")
public class BsOrderChildServiceImpl implements BsOrderChildService {
    @Resource
    private BsOrderChildMapper orderChildMapper;

    @Resource
    private GoodsUserAddressService goodsUserAddressService;

    @Resource
    private BsOrderGoodsService orderGoodsService;
    @Resource
    private GoodsVpdService goodsVpdService;

    @Override
    public void editData(BsOrderChild data) {
        data.setUpdateTime(new Date());
        if (data.getId() == null) {
            data.setCreateTime(new Date());
            orderChildMapper.insert(data);
        } else {
            orderChildMapper.updateByPrimaryKey(data);
        }
    }

    @Override
    public OrderChildModel getDetail(String childOrderNo) {
        BsOrderChildExample example = new BsOrderChildExample();
        example.createCriteria().andChildOrderNoEqualTo(childOrderNo);
        List<BsOrderChild> list = orderChildMapper.selectByExample(example);
        if (!list.isEmpty()) {
            OrderChildModel childModel = new OrderChildModel();
            BeanUtils.copyProperties(list.get(0), childModel);
            return childModel;
        }
        return null;

    }

    @Override
    public List<OrderChildModel> getOrderChildListByOrderNo(String orderNo) {
        BsOrderChildExample example = new BsOrderChildExample();
        example.createCriteria().andOrderNoEqualTo(orderNo);
        example.setOrderByClause("id");
        List<BsOrderChild> list = orderChildMapper.selectByExample(example);

        List<OrderChildModel> orderChildModelList = new ArrayList<>();

        for (BsOrderChild orderChild : list) {
            OrderChildModel childModel = new OrderChildModel();
            BeanUtils.copyProperties(orderChild, childModel);

            if (childModel.getProductType().equals(OrderChildProductTypeEnum.type1.getCode())) {
                BsOrderGoods orderGoods = orderGoodsService.findGoodsOrder(orderNo);
                if (orderGoods != null) {
                    GoodsUserAddress address;
                    if (orderGoods.getDeliveryAddressId() != null) {
                        address = goodsUserAddressService.queryDetail(orderGoods.getDeliveryAddressId());
                    } else {
                        Map<String , Object> map = new HashMap<>();
                        map.put("userId" , orderGoods.getUserId());
                        address = goodsUserAddressService.queryDetailByMap(map);
                    }
       
                    JSONObject object;
                    if (childModel.getBusiness() == null) {
                        object = new JSONObject();
                    } else {
                        object = new JSONObject((Map<String, Object>) childModel.getBusiness());
                    }

                    object.put("address", address);
                    object.put("orderGoodsId", orderGoods.getId());
                    childModel.setBusiness(object);

                }
            } else if (childModel.getProductType().equals(OrderChildProductTypeEnum.type2.getCode())) {
                childModel.setBusiness(goodsVpdService.queryDetailBySpecsId(childModel.getProductSpecId()));
            }
            orderChildModelList.add(childModel);
        }
        return orderChildModelList;
    }

    @Override
    public long getUndoneChildOrder(String orderNo) {
        BsOrderChildExample example = new BsOrderChildExample();
        example.createCriteria().andOrderNoEqualTo(orderNo).andStatusNotEqualTo(OrderChildStatusEnum.status3.getCode());
        return orderChildMapper.countByExample(example);
    }
}
